# Nextline Alert

[![PyPI - Version](https://img.shields.io/pypi/v/nextline-alert.svg)](https://pypi.org/project/nextline-alert)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/nextline-alert.svg)](https://pypi.org/project/nextline-alert)

A plugin for [nextline-graphql](https://github.com/simonsobs/nextline-graphql).
Emit alerts to [Campana](https://github.com/simonsobs/campana)

---

**Table of Contents**

- [Nextline Alert](#nextline-alert)
  - [Installation](#installation)
  - [Configuration](#configuration)
  - [License](#license)
  - [Contact](#contact)

## Installation

```console
pip install nextline-alert
```

## Configuration

| Environment variable          | Default value             | Description          |
| ----------------------------- | ------------------------- | -------------------- |
| `NEXTLINE_ALERT__CAMPANA_URL` | `http://httpbin.org/post` | The CAMPANA endpoint |
| `NEXTLINE_ALERT__PLATFORM`    | `localhost`               | The platform name    |

## License

`nextline-alert` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.

## Contact

- [Tai Sakuma](https://github.com/TaiSakuma) <span itemscope itemtype="https://schema.org/Person"><a itemprop="sameAs" content="https://orcid.org/0000-0003-3225-9861" href="https://orcid.org/0000-0003-3225-9861" target="orcid.widget" rel="me noopener noreferrer" style="vertical-align:text-top;"><img src="https://orcid.org/sites/default/files/images/orcid_16x16.png" style="width:1em;margin-right:.5em;" alt="ORCID iD icon"></a></span>
